==> haskell-hlint-2.0.8-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hlint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.8
id: hlint-2.0.8-AxCGTe89vDHHxkJyAUWPHp
key: hlint-2.0.8-AxCGTe89vDHHxkJyAUWPHp
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.All Config.Compute
                Config.Haskell Config.Type Config.Yaml HSE.All HSE.Bracket
                HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Export
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Restrict Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: 78c0eb73cc575ca755505f613a123327
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-2.0.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-2.0.8
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.8-AxCGTe89vDHHxkJyAUWPHp
depends:
    ansi-terminal-0.6.3.1-C5gpy392zkR1qCeRuDySE4 base-4.9.0.0
    bytestring-0.10.8.1 cmdargs-0.10.17-Hs2S0uL9DmQG8vy4Sf8xLT
    containers-0.5.7.1 cpphs-1.20.5-9Lrl39xU7l95nscj9g2g6B
    directory-1.2.6.2 extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
    filepath-1.4.1.0 haskell-src-exts-1.18.2-HPJDx1bP0PTGB2XZpVQJ3s
    hscolour-1.24.1-H2EUF2muHY0JRKOYWigHLc process-1.4.2.0
    refact-0.3.0.2-JBbxaqExt5tJMSfYCjPwkx
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    uniplate-1.6.12-Kik3YoqrZlAKSEaGvuxE4g
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    yaml-0.8.23-2g4ghz9iEN3Bv19gf809hJ
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hlint-2.0.8-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hlint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.8
id: hlint-2.0.8-3wVX9X5wxYNHyRBL3l9h8R
key: hlint-2.0.8-3wVX9X5wxYNHyRBL3l9h8R
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.All Config.Compute
                Config.Haskell Config.Type Config.Yaml HSE.All HSE.Bracket
                HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Export
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Restrict Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: 927b07414e5b5b51bb6f3c242ee753b2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-2.0.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-2.0.8
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.8-3wVX9X5wxYNHyRBL3l9h8R
depends:
    ansi-terminal-0.6.3.1-C5gpy392zkR1qCeRuDySE4 base-4.9.0.0
    bytestring-0.10.8.1 cmdargs-0.10.17-Hs2S0uL9DmQG8vy4Sf8xLT
    containers-0.5.7.1 cpphs-1.20.5-9Lrl39xU7l95nscj9g2g6B
    directory-1.2.6.2 extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
    filepath-1.4.1.0 haskell-src-exts-1.18.2-HPJDx1bP0PTGB2XZpVQJ3s
    hscolour-1.24.1-H2EUF2muHY0JRKOYWigHLc process-1.4.2.0
    refact-0.3.0.2-JBbxaqExt5tJMSfYCjPwkx
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    uniplate-1.6.12-Kik3YoqrZlAKSEaGvuxE4g
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    yaml-0.8.23-GVM4r8hhN8WEBBJV7tAgAb
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
